@@ -786,7 +786,7 @@ class PublisherThread(Thread):
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
 
-                    self.publisher.close()
+                    #self.publisher.close()
 
                     self.publisher = Publisher(connection=self.amqpconn,
                                    exchange=self.server_id + "_server_exchange",
